<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans svn://trac.rezo.net/spip/spip/ecrire/lang/
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
	'0_langue' => 'Français [fr]',
	'0_liste' => 'spip-dev@rezo.net',
	'0_mainteneur' => 'spip-dev@rezo.net',

	// A
	'access_interface_graphique' => 'Retour à l’interface graphique complète',
	'access_mode_texte' => 'Afficher l’interface textuelle simplifiée',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Modifier cet article',
	'admin_modifier_auteur' => 'Modifier cet auteur',
	'admin_modifier_breve' => 'Modifier cette brève',
	'admin_modifier_mot' => 'Modifier ce mot-clé',
	'admin_modifier_rubrique' => 'Modifier cette rubrique',
	'admin_recalculer' => 'Recalculer cette page',
	'afficher_calendrier' => 'Afficher le calendrier',
	'afficher_trad' => 'afficher les traductions',
	'alerte_maj_impossible' => '<b>Alerte !</b> La mise à jour de la base SQL vers la version @version@ est impossible, peut-être à cause d’un problème de droit de modification sur la base de données. Veuillez contacter votre hébergeur.',
	'alerte_modif_info_concourante' => 'ATTENTION : Cette information a été modifiée par ailleurs. La valeur actuelle est :',
	'analyse_xml' => 'Analyse XML',
	'annuler' => 'Annuler',
	'antispam_champ_vide' => 'Veuillez laisser ce champ vide :',
	'articles_recents' => 'Articles les plus récents',
	'avis_1_erreur_saisie' => 'Il y a 1 erreur dans votre saisie, veuillez vérifier les informations.',
	'avis_archive_incorrect' => 'le fichier archive n’est pas un fichier SPIP',
	'avis_archive_invalide' => 'le fichier archive n’est pas valide',
	'avis_attention' => 'ATTENTION !',
	'avis_champ_incorrect_type_objet' => 'Nom de champ incorrect @name@ pour objet de type @type@',
	'avis_colonne_inexistante' => 'La colonne @col@ n’existe pas',
	'avis_erreur' => 'Erreur : voir ci-dessous',
	'avis_erreur_connexion' => 'Erreur de connexion',
	'avis_erreur_cookie' => 'problème de cookie',
	'avis_erreur_fonction_contexte' => 'Erreur de programmation. Cette fonction ne doit pas être appelée dans ce contexte.',
	'avis_erreur_mysql' => 'Erreur SQL',
	'avis_erreur_sauvegarde' => 'Erreur dans la sauvegarde (@type@ @id_objet@) !',
	'avis_erreur_visiteur' => 'Problème d’accès à l’espace privé',
	'avis_nb_erreurs_saisie' => 'Il y a @nb@ erreurs dans votre saisie, veuillez vérifier les informations.',

	// B
	'barre_a_accent_grave' => 'Insérer un A accent grave majuscule',
	'barre_aide' => 'Utilisez les raccourcis typographiques pour enrichir votre mise en page',
	'barre_e_accent_aigu' => 'Insérer un E accent aigu majuscule',
	'barre_eo' => 'Insérer un E dans l’O',
	'barre_eo_maj' => 'Insérer un E dans l’O majuscule',
	'barre_euro' => 'Insérer le symbole €',
	'barre_gras' => 'Mettre en {{gras}}',
	'barre_guillemets' => 'Entourer de « guillemets »',
	'barre_guillemets_simples' => 'Entourer de “guillemets de second niveau”',
	'barre_intertitre' => 'Transformer en {{{intertitre}}}',
	'barre_italic' => 'Mettre en {italique}',
	'barre_lien' => 'Transformer en [lien hypertexte->http://...]',
	'barre_lien_input' => 'Veuillez indiquer l’adresse de votre lien (vous pouvez indiquer une adresse Web sous la forme http://www.monsite/com ou simplement indiquer le numéro d’un article de ce site.',
	'barre_note' => 'Transformer en [[Note de bas de page]]',
	'barre_paragraphe' => 'Créer un paragraphe',
	'barre_quote' => '<quote>Citer un message</quote>',
	'bouton_changer' => 'Changer',
	'bouton_chercher' => 'Chercher',
	'bouton_choisir' => 'Choisir',
	'bouton_deplacer' => 'Déplacer',
	'bouton_download' => 'Télécharger',
	'bouton_enregistrer' => 'Enregistrer',
	'bouton_radio_desactiver_messagerie_interne' => 'Désactiver la messagerie interne',
	'bouton_radio_envoi_annonces' => 'Envoyer les annonces éditoriales',
	'bouton_radio_non_envoi_annonces' => 'Ne pas envoyer d’annonces',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Ne pas envoyer la liste des nouveautés',
	'bouton_recharger_page' => 'recharger cette page',
	'bouton_telecharger' => 'Télécharger',
	'bouton_upload' => 'Téléverser',
	'bouton_valider' => 'Valider',

	// C
	'cal_apresmidi' => 'après-midi',
	'cal_jour_entier' => 'jour entier',
	'cal_matin' => 'matin',
	'cal_par_jour' => 'calendrier par jour',
	'cal_par_mois' => 'calendrier par mois',
	'cal_par_semaine' => 'calendrier par semaine',
	'choix_couleur_interface' => 'couleur ',
	'choix_interface' => 'choix  de l’interface',
	'colonne' => 'Colonne',
	'confirm_changer_statut' => 'Attention, vous avez demandé à changer le statut de cet élément. Souhaitez-vous continuer ?',
	'correcte' => 'correcte', # chaine utilisée dans le debugueur : "validation .. impossible" ou "validation .. correcte"

	// D
	'date_aujourdhui' => 'aujourd’hui',
	'date_avant_jc' => 'av. J.C.',
	'date_dans' => 'dans @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'demain',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ à @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ de @heure_debut@ à @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ de @heure_debut@@dtabbr@ à @dtend@@heure_fin@@dtabbr@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => 'le @nomjour@ @date@',
	'date_fmt_periode' => 'Du @date_debut@ au @date_fin@',
	'date_fmt_periode_abbr' => 'Du @dtart@@date_debut@@dtabbr@ au @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'Du',
	'date_fmt_periode_to' => 'au',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'heures',
	'date_hier' => 'hier',
	'date_il_y_a' => 'il y a @delai@',
	'date_jnum1' => '1er',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'dimanche',
	'date_jour_1_abbr' => 'dim.',
	'date_jour_1_initiale' => 'd.',
	'date_jour_2' => 'lundi',
	'date_jour_2_abbr' => 'lun.',
	'date_jour_2_initiale' => 'l.',
	'date_jour_3' => 'mardi',
	'date_jour_3_abbr' => 'mar.',
	'date_jour_3_initiale' => 'm.',
	'date_jour_4' => 'mercredi',
	'date_jour_4_abbr' => 'mer.',
	'date_jour_4_initiale' => 'm.',
	'date_jour_5' => 'jeudi',
	'date_jour_5_abbr' => 'jeu.',
	'date_jour_5_initiale' => 'j.',
	'date_jour_6' => 'vendredi',
	'date_jour_6_abbr' => 'ven.',
	'date_jour_6_initiale' => 'v.',
	'date_jour_7' => 'samedi',
	'date_jour_7_abbr' => 'sam.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'jours',
	'date_minutes' => 'minutes',
	'date_mois' => 'mois',
	'date_mois_1' => 'janvier',
	'date_mois_10' => 'octobre',
	'date_mois_10_abbr' => 'oct.',
	'date_mois_11' => 'novembre',
	'date_mois_11_abbr' => 'nov.',
	'date_mois_12' => 'décembre',
	'date_mois_12_abbr' => 'déc.',
	'date_mois_1_abbr' => 'janv.',
	'date_mois_2' => 'février',
	'date_mois_2_abbr' => 'févr.',
	'date_mois_3' => 'mars',
	'date_mois_3_abbr' => 'mars',
	'date_mois_4' => 'avril',
	'date_mois_4_abbr' => 'avr.',
	'date_mois_5' => 'mai',
	'date_mois_5_abbr' => 'mai',
	'date_mois_6' => 'juin',
	'date_mois_6_abbr' => 'juin',
	'date_mois_7' => 'juillet',
	'date_mois_7_abbr' => 'juil.',
	'date_mois_8' => 'août',
	'date_mois_8_abbr' => 'août',
	'date_mois_9' => 'septembre',
	'date_mois_9_abbr' => 'sept.',
	'date_saison_1' => 'hiver',
	'date_saison_2' => 'printemps',
	'date_saison_3' => 'été',
	'date_saison_4' => 'automne',
	'date_secondes' => 'secondes',
	'date_semaines' => 'semaines',
	'date_un_mois' => 'mois',
	'date_une_heure' => 'heure',
	'date_une_minute' => 'minute',
	'date_une_seconde' => 'seconde',
	'date_une_semaine' => 'semaine',
	'dirs_commencer' => ' afin de commencer réellement l’installation',
	'dirs_preliminaire' => 'Préliminaire : <b>Régler les droits d’accès</b>',
	'dirs_probleme_droits' => 'Problème de droits d’accès',
	'dirs_repertoires_absents' => '<p><b>Les répertoires suivants n’ont pas été trouvés :</b></p><ul>@bad_dirs@</ul>
  <p>Il est probable que cela soit dû à un problème de mauvaise mise en majuscules ou minuscules.
  Vérifiez que les minuscules et majuscules de ces répertoires concordent bien avec ce qui est affiché
  ci-dessus ; si ce n’est pas le cas, renommez les répertoires avec votre logiciel FTP de façon à corriger l’erreur.</p>
  <p>Une fois cette manipulation effectuée, vous pourrez ',
	'dirs_repertoires_suivants' => '<p><b>Les répertoires suivants ne sont pas accessibles en écriture :</b></p> <ul>@bad_dirs@</ul>
  <p>Pour y remédier, utilisez votre client FTP afin de régler les droits d’accès de chacun
  de ces répertoires. La procédure est expliquée en détail dans le guide d’installation.</p>
  <p>Une fois cette manipulation effectuée, vous pourrez ',
	'double_occurrence' => 'Double occurrence de @balise@',

	// E
	'en_cours' => 'en cours',
	'envoi_via_le_site' => 'Envoi via le site',
	'erreur' => 'Erreur',
	'erreur_balise_non_fermee' => 'dernière balise non refermée :',
	'erreur_technique_ajaxform' => 'Oups. Une erreur inattendue a empêché de soumettre le formulaire. Vous pouvez essayer à nouveau.',
	'erreur_technique_enregistrement_champs' => 'Une erreur technique a empêché l’enregistrement correct du champ @champs@.',
	'erreur_technique_enregistrement_impossible' => 'Une erreur technique a empêché l’enregistrement.',
	'erreur_texte' => 'erreur(s)',
	'etape' => 'Étape',

	// F
	'fichier_introuvable' => 'Fichier @fichier@ introuvable',
	'form_auteur_confirmation' => 'Confirmez votre adresse email',
	'form_auteur_email_modifie' => 'Votre adresse email a été modifiée.',
	'form_auteur_envoi_mail_confirmation' => 'Un courrier électronique de confirmation vient d’être envoyé à @email@. Vous devrez visiter l’adresse Web mentionnée dans ce courrier pour valider votre adresse mail.',
	'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demandé à changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter à
l’adresse ci-dessous (dans le cas contraire, votre demande
sera ignorée) :

    @url@
',
	'form_deja_inscrit' => 'Vous êtes déjà inscrit.',
	'form_email_non_valide' => 'Votre adresse email n’est pas valide.',
	'form_forum_access_refuse' => 'Vous n’avez plus accès à ce site.',
	'form_forum_bonjour' => 'Bonjour @nom@,',
	'form_forum_confirmer_email' => 'Pour confirmer votre adresse email, rendez-vous à cette adresse : @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Cette adresse email est déjà enregistrée, vous pouvez donc utiliser votre mot de passe habituel.',
	'form_forum_identifiant_mail' => 'Votre nouvel identifiant vient de vous être envoyé par email.',
	'form_forum_identifiants' => 'Identifiants personnels',
	'form_forum_indiquer_nom_email' => 'Indiquez ici votre nom et votre adresse email. Votre identifiant personnel vous parviendra rapidement, par courrier électronique.',
	'form_forum_login' => 'login :',
	'form_forum_message_auto' => '(ceci est un message automatique)',
	'form_forum_pass' => 'mot de passe :',
	'form_forum_probleme_mail' => 'Problème de mail : l’identifiant ne peut pas être envoyé.',
	'form_forum_voici1' => 'Voici vos identifiants pour pouvoir participer à la vie du site "@nom_site_spip@" (@adresse_site@) :',
	'form_forum_voici2' => 'Voici vos identifiants pour proposer des articles sur
le site "@nom_site_spip@" (@adresse_login@) :',
	'form_indiquer_email' => 'Veuillez indiquer votre adresse email.',
	'form_indiquer_nom' => 'Veuillez indiquer votre nom.',
	'form_indiquer_nom_site' => 'Veuillez indiquer le nom de votre site.',
	'form_pet_deja_enregistre' => 'Ce site est déjà enregistré',
	'form_pet_signature_pasprise' => 'Votre signature n’est pas prise en compte.',
	'form_prop_confirmer_envoi' => 'Confirmer l’envoi',
	'form_prop_description' => 'Description/commentaire',
	'form_prop_enregistre' => 'Votre proposition est enregistrée, elle apparaîtra en ligne après validation par les responsables de ce site.',
	'form_prop_envoyer' => 'Envoyer un message',
	'form_prop_indiquer_email' => 'Veuillez indiquer une adresse email valide',
	'form_prop_indiquer_nom_site' => 'Veuillez indiquer le nom du site.',
	'form_prop_indiquer_sujet' => 'Veuillez indiquer un sujet',
	'form_prop_message_envoye' => 'Message envoyé',
	'form_prop_non_enregistre' => 'Votre proposition n’a pas été enregistrée.',
	'form_prop_sujet' => 'Sujet',
	'form_prop_url_site' => 'Adresse URL du site',
	'forum_non_inscrit' => 'Vous n’êtes pas inscrit, ou l’adresse ou le mot de passe sont erronés.',
	'forum_par_auteur' => 'par @auteur@',
	'forum_titre_erreur' => 'Erreur...',

	// I
	'ical_texte_rss_articles' => 'Le fichier « backend » des articles de ce site se trouve à l’adresse :',
	'ical_texte_rss_articles2' => 'Vous pouvez également obtenir des fichiers « backend » pour les articles de chaque rubrique du site :',
	'ical_texte_rss_breves' => 'Il existe de plus un fichier contenant les brèves du site. En précisant un numéro de rubrique, vous obtiendrez uniquement les brèves de cette rubrique.',
	'icone_a_suivre' => 'À suivre',
	'icone_admin_site' => 'Administration du site',
	'icone_agenda' => 'Agenda',
	'icone_aide_ligne' => 'Aide',
	'icone_articles' => 'Articles',
	'icone_auteurs' => 'Auteurs',
	'icone_brouteur' => 'Navigation rapide',
	'icone_configuration_site' => 'Configuration',
	'icone_configurer_site' => 'Configurer votre site',
	'icone_creer_nouvel_auteur' => 'Créer un nouvel auteur',
	'icone_creer_rubrique' => 'Créer une rubrique',
	'icone_creer_sous_rubrique' => 'Créer une sous-rubrique',
	'icone_deconnecter' => 'Se déconnecter',
	'icone_discussions' => 'Discussions',
	'icone_doc_rubrique' => 'Documents des rubriques',
	'icone_ecrire_article' => 'Écrire un nouvel article',
	'icone_edition_site' => 'Édition',
	'icone_gestion_langues' => 'Gestion des langues',
	'icone_informations_personnelles' => 'Informations personnelles',
	'icone_interface_complet' => 'interface complète',
	'icone_interface_simple' => 'Interface simplifiée',
	'icone_maintenance_site' => 'Maintenance du site',
	'icone_messagerie_personnelle' => 'Messagerie personnelle',
	'icone_repartition_debut' => 'Afficher la répartition depuis le début',
	'icone_rubriques' => 'Rubriques',
	'icone_sauver_site' => 'Sauvegarde du site',
	'icone_site_entier' => 'Tout le site',
	'icone_sites_references' => 'Sites référencés',
	'icone_statistiques' => 'Statistiques du site',
	'icone_suivi_activite' => 'Suivre la vie du site',
	'icone_suivi_actualite' => 'Évolution du site',
	'icone_suivi_pettions' => 'Suivre/gérer les pétitions',
	'icone_suivi_revisions' => 'Modifications des articles',
	'icone_supprimer_document' => 'Supprimer ce document',
	'icone_supprimer_image' => 'Supprimer cette image',
	'icone_tous_articles' => 'Tous vos articles',
	'icone_tous_auteur' => 'Tous les auteurs',
	'icone_tous_visiteur' => 'Tous les visiteurs',
	'icone_visiter_site' => 'Voir le site public',
	'icone_voir_en_ligne' => 'Voir en ligne',
	'img_indisponible' => 'image indisponible',
	'impossible' => 'impossible',
	'info_a_suivre' => 'À SUIVRE »',
	'info_acces_interdit' => 'Accès interdit',
	'info_acces_refuse' => 'Accès refusé',
	'info_action' => 'Action : @action@',
	'info_administrer_rubriques' => 'Vous pouvez administrer cette rubrique et ses sous-rubriques',
	'info_adresse_non_indiquee' => 'Vous n’avez pas indiqué d’adresse à tester !',
	'info_aide' => 'AIDE :',
	'info_ajouter_mot' => 'Ajouter ce mot',
	'info_annonce' => 'ANNONCE',
	'info_annonces_generales' => 'Annonces générales :',
	'info_article_propose' => 'Article proposé',
	'info_article_publie' => 'Article publié',
	'info_article_redaction' => 'Article en cours de rédaction',
	'info_article_refuse' => 'Article refusé',
	'info_article_supprime' => 'Article supprimé',
	'info_articles' => 'Articles',
	'info_articles_a_valider' => 'Les articles à valider',
	'info_articles_nb' => '@nb@ articles',
	'info_articles_proposes' => 'Articles proposés',
	'info_articles_un' => '1 article',
	'info_auteurs_nombre' => 'auteur(s) :',
	'info_authentification_ftp' => 'Authentification (par FTP).',
	'info_breves_2' => 'brèves',
	'info_breves_nb' => '@nb@ brèves',
	'info_breves_un' => '1 brève',
	'info_connexion_refusee' => 'Connexion refusée',
	'info_contact_developpeur' => 'Veuillez contacter un développeur.',
	'info_contenance' => 'Ce site contient :',
	'info_contribution' => 'contributions',
	'info_copyright' => '@spip@ est un logiciel libre distribué @lien_gpl@.',
	'info_copyright_doc' => 'Pour plus d’informations, voir le site <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'sous licence GPL',
	'info_cours_edition' => 'En cours de rédaction',
	'info_creer_repertoire' => 'Veuillez créer un fichier ou un répertoire nommé :',
	'info_creer_repertoire_2' => 'à l’intérieur du sous-répertoire <b>@repertoire@</b>, puis :',
	'info_creer_vignette' => 'création automatique de la vignette',
	'info_creerdansrubrique_non_autorise' => 'Vous n’avez pas de droits suffisants pour créer un contenu dans cette rubrique',
	'info_deplier' => 'Déplier',
	'info_descriptif_nombre' => 'descriptif(s) :',
	'info_description' => 'Description :',
	'info_description_2' => 'Description :',
	'info_dimension' => 'Dimensions :',
	'info_documents_nb' => '@nb@ documents',
	'info_documents_un' => '1 document',
	'info_ecire_message_prive' => 'Écrire un message privé',
	'info_email_invalide' => 'Adresse email invalide.',
	'info_en_cours_validation' => 'Vos articles en cours de rédaction',
	'info_en_ligne' => 'Actuellement en ligne :',
	'info_envoyer_message_prive' => 'Envoyer un message privé à cet auteur',
	'info_erreur_requete' => 'Erreur dans la requête :',
	'info_erreur_squelette2' => 'Aucun squelette <b>@fichier@</b> n’est disponible...',
	'info_erreur_systeme' => 'Erreur système (errno @errsys@)',
	'info_erreur_systeme2' => 'Le disque dur est peut-être plein, ou la base de données endommagée.<br />
<span style="color:red;">Essayez de <a href=\'@script@\'>réparer la base</a>, ou contactez votre hébergeur.</span>',
	'info_fini' => 'C’est fini !',
	'info_format_image' => 'Formats d’images pouvant être utilisées pour créer des vignettes : @gd_formats@.',
	'info_format_non_defini' => 'format non défini',
	'info_grand_ecran' => 'Grand écran',
	'info_image_aide' => 'AIDE',
	'info_image_process_titre' => 'Méthode de fabrication des vignettes',
	'info_impossible_lire_page' => '<b>Erreur !</b> Impossible de lire la page <tt><html>@test_proxy@</html></tt> à travers le proxy ',
	'info_installation_systeme_publication' => 'Installation du système de publication...',
	'info_installer_documents' => 'Vous pouvez installer automatiquement tous les documents contenus dans le dossier @upload@.',
	'info_installer_ftp' => 'En tant qu’administrateur, vous pouvez installer (par FTP) des fichiers dans le dossier @upload@ pour ensuite les sélectionner directement ici.',
	'info_installer_images' => 'Vous pouvez installer des images aux formats JPEG, GIF et PNG.',
	'info_installer_images_dossier' => 'Installer des images dans le dossier @upload@ pour pouvoir les sélectionner ici.',
	'info_interface_complete' => 'interface complète',
	'info_interface_simple' => 'Interface simplifiée',
	'info_joindre_document_article' => 'Vous pouvez joindre à cet article des documents de type',
	'info_joindre_document_rubrique' => 'Vous pouvez ajouter dans cette rubrique des documents de type',
	'info_joindre_documents_article' => 'Vous pouvez joindre à votre article des documents de type :',
	'info_l_article' => 'l’article',
	'info_la_breve' => 'la brève',
	'info_la_rubrique' => 'la rubrique',
	'info_langue_principale' => 'Langue principale du site',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixels',
	'info_les_auteurs_1' => 'par @les_auteurs@',
	'info_logo_format_interdit' => 'Seuls les logos aux formats @formats@ sont autorisés.',
	'info_logo_max_poids' => 'Les logos doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
	'info_mail_fournisseur' => 'vous@fournisseur.com',
	'info_message_2' => 'MESSAGE',
	'info_message_supprime' => 'MESSAGE SUPPRIMÉ',
	'info_messages_nb' => '@nb@ messages',
	'info_messages_un' => '1 message',
	'info_mise_en_ligne' => 'Date de mise en ligne :',
	'info_modification_parametres_securite' => 'modifications des paramètres de sécurité',
	'info_mois_courant' => 'Dans le courant du mois :',
	'info_mot_cle_ajoute' => 'Le mot-clé suivant a été ajouté à',
	'info_multi_herit' => 'Langue par défaut',
	'info_multi_langues_soulignees' => 'Les <u>langues soulignées</u> bénéficient d’une traduction totale ou partielle des textes de l’interface. Si vous sélectionnez ces langues, de nombreux éléments du site public (dates, formulaires) seront automatiquement traduits. Pour les langues non soulignées, ces éléments apparaîtront dans la langue principale du site.',
	'info_multilinguisme' => 'Multilinguisme',
	'info_nom_non_utilisateurs_connectes' => 'Votre nom n’apparaît pas dans la liste des utilisateurs connectés.',
	'info_nom_utilisateurs_connectes' => 'Votre nom apparaît dans la liste des utilisateurs connectés.',
	'info_nombre_en_ligne' => 'Actuellement en ligne :',
	'info_non_resultat' => 'Aucun résultat pour "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Vous n’utilisez pas la messagerie interne de ce site.',
	'info_nouveau_message' => 'VOUS AVEZ UN NOUVEAU MESSAGE',
	'info_nouveaux_messages' => 'VOUS AVEZ @total_messages@ NOUVEAUX MESSAGES',
	'info_numero_abbreviation' => 'N° ',
	'info_obligatoire' => 'Cette information est obligatoire',
	'info_pense_bete' => 'PENSE-BÊTE',
	'info_petit_ecran' => 'Petit écran',
	'info_petition_close' => 'Pétition close',
	'info_pixels' => 'pixels',
	'info_plusieurs_mots_trouves' => 'Plusieurs mots-clés trouvés pour "@cherche_mot@" :',
	'info_portfolio_automatique' => 'Portfolio automatique :',
	'info_premier_resultat' => '[@debut_limit@ premiers résultats sur @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ premiers résultats sur @total@]',
	'info_propose_1' => '[@nom_site_spip@] Propose : @titre@',
	'info_propose_2' => 'Article proposé
---------------',
	'info_propose_3' => 'L’article "@titre@" est proposé à la publication.',
	'info_propose_4' => 'Vous êtes invité à venir le consulter et à donner votre opinion',
	'info_propose_5' => 'dans le forum qui lui est attaché. Il est disponible à l’adresse :',
	'info_publie_01' => 'L’article "@titre@" a été validé par @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLIE : @titre@',
	'info_publie_2' => 'Article publié
--------------',
	'info_rechercher' => 'Rechercher',
	'info_rechercher_02' => 'Rechercher :',
	'info_remplacer_vignette' => 'Remplacer la vignette par défaut par un logo personnalisé :',
	'info_rubriques_nb' => '@nb@ rubriques',
	'info_rubriques_un' => '1 rubrique',
	'info_sans_titre_2' => 'sans titre',
	'info_selectionner_fichier' => 'Vous pouvez sélectionner un fichier du dossier @upload@',
	'info_selectionner_fichier_2' => 'Sélectionner un fichier :',
	'info_sites_nb' => '@nb@ sites',
	'info_sites_un' => '1 site',
	'info_supprimer_vignette' => 'supprimer la vignette',
	'info_symbole_bleu' => 'Le symbole <b>bleu</b> indique un <b>pense-bête</b> : c’est-à-dire un message à votre usage personnel.',
	'info_symbole_jaune' => 'Le symbole <b>jaune</b> indique une <b>annonce à tous les rédacteurs</b> : modifiable par tous les administrateurs, et visible par tous les rédacteurs.',
	'info_symbole_vert' => 'Le symbole <b>vert</b> indique les <b>messages échangés avec d’autres utilisateurs</b> du site.',
	'info_telecharger_nouveau_logo' => 'Télécharger un nouveau logo :',
	'info_telecharger_ordinateur' => 'Télécharger depuis votre ordinateur :',
	'info_tous_resultats_enregistres' => '[tous les résultats sont enregistrés]',
	'info_tout_afficher' => 'Tout afficher',
	'info_travaux_texte' => 'Ce site n’est pas encore configuré. Revenez plus tard...',
	'info_travaux_titre' => 'Site en travaux',
	'info_trop_resultat' => 'Trop de résultats pour "@cherche_mot@" ; veuillez affiner la recherche.',
	'info_utilisation_messagerie_interne' => 'Vous utilisez la messagerie interne de ce site.',
	'info_valider_lien' => 'valider ce lien',
	'info_verifier_image' => ', veuillez vérifier que vos images ont été transférées correctement.',
	'info_vignette_defaut' => 'Vignette par défaut',
	'info_vignette_personnalisee' => 'Vignette personnalisée',
	'info_visite' => 'visite :',
	'info_vos_rendez_vous' => 'Vos rendez-vous à venir',
	'infos_vos_pense_bete' => 'Vos pense-bêtes',

	// L
	'label_ajout_id_rapide' => 'Ajout rapide',
	'label_poids_fichier' => 'Taille',
	'lien_afficher_icones_seuls' => 'Afficher uniquement les icones',
	'lien_afficher_texte_icones' => 'Afficher les icones et le texte',
	'lien_afficher_texte_seul' => 'Afficher uniquement le texte',
	'lien_liberer' => 'libérer',
	'lien_liberer_tous' => 'Tout libérer',
	'lien_nouvea_pense_bete' => 'NOUVEAU PENSE-BÊTE',
	'lien_nouveau_message' => 'NOUVEAU MESSAGE',
	'lien_nouvelle_annonce' => 'NOUVELLE ANNONCE',
	'lien_petitions' => 'PÉTITION',
	'lien_popularite' => 'popularité : @popularite@%',
	'lien_racine_site' => 'RACINE DU SITE',
	'lien_reessayer' => 'réessayer',
	'lien_repondre_message' => 'Répondre à ce message',
	'lien_supprimer' => 'supprimer',
	'lien_tout_afficher' => 'Tout afficher',
	'lien_visite_site' => 'visiter ce site',
	'lien_visites' => '@visites@ visites',
	'lien_voir_auteur' => 'Voir cet auteur',
	'ligne' => 'Ligne',
	'login' => 'Connexion',
	'login_acces_prive' => 'accès à l’espace privé',
	'login_autre_identifiant' => 'se connecter sous un autre identifiant',
	'login_cookie_accepte' => 'Veuillez régler votre navigateur pour qu’il les accepte (au moins pour ce site).',
	'login_cookie_oblige' => 'Pour vous identifier de façon sûre sur ce site, vous devez accepter les cookies.',
	'login_deconnexion_ok' => 'Déconnexion effectuée.',
	'login_erreur_pass' => 'Erreur de mot de passe.',
	'login_espace_prive' => 'espace privé',
	'login_identifiant_inconnu' => 'L’identifiant « @login@ » est inconnu.',
	'login_login' => 'Login :',
	'login_login2' => 'Login ou adresse email :',
	'login_login_pass_incorrect' => '(Login ou mot de passe incorrect.)',
	'login_motpasseoublie' => 'mot de passe oublié ?',
	'login_non_securise' => 'Attention, ce formulaire n’est pas sécurisé.
			Si vous ne voulez pas que votre mot de passe puisse être
			intercepté sur le réseau, veuillez activer Javascript
			dans votre navigateur et',
	'login_nouvelle_tentative' => 'Nouvelle tentative',
	'login_par_ici' => 'Vous êtes enregistré... par ici...',
	'login_pass2' => 'Mot de passe :',
	'login_preferez_refuser' => '<b>Si vous préférez refuser les cookies</b>, une autre méthode de connexion (moins sécurisée) est à votre disposition :',
	'login_recharger' => 'recharger cette page',
	'login_rester_identifie' => 'Rester identifié quelques jours',
	'login_retour_public' => 'Retour au site public',
	'login_retour_site' => 'Retour au site public',
	'login_retoursitepublic' => 'retour au site public',
	'login_sans_cookie' => 'Identification sans cookie',
	'login_securise' => 'Login sécurisé',
	'login_sinscrire' => 's’inscrire',
	'login_test_navigateur' => 'test navigateur/reconnexion',
	'login_verifiez_navigateur' => '(Vérifiez toutefois que votre navigateur n’a pas mémorisé votre mot de passe...)',

	// M
	'masquer_colonne' => 'Masquer cette colonne',
	'masquer_trad' => 'masquer les traductions',
	'module_fichiers_langues' => 'Fichiers de langue',

	// N
	'navigateur_pas_redirige' => 'Si votre navigateur n’est pas redirigé, cliquez ici pour continuer.',
	'numero' => 'Numéro',

	// O
	'occurence' => 'Occurrence',
	'onglet_affacer_base' => 'Effacer la base',
	'onglet_auteur' => 'L’auteur',
	'onglet_contenu_site' => 'Contenu du site',
	'onglet_evolution_visite_mod' => 'Évolution',
	'onglet_fonctions_avances' => 'Fonctions avancées',
	'onglet_informations_personnelles' => 'Informations personnelles',
	'onglet_interactivite' => 'Interactivité',
	'onglet_messagerie' => 'Messagerie',
	'onglet_repartition_rubrique' => 'Répartition par rubriques',
	'onglet_save_restaur_base' => 'Sauvegarder/restaurer la base',
	'onglet_vider_cache' => 'Vider le cache',

	// P
	'pass_choix_pass' => 'Veuillez choisir votre nouveau mot de passe :',
	'pass_erreur' => 'Erreur',
	'pass_erreur_acces_refuse' => '<b>Erreur :</b> vous n’avez plus accès à ce site.',
	'pass_erreur_code_inconnu' => '<b>Erreur :</b> ce code ne correspond à aucun des visiteurs ayant accès à ce site.',
	'pass_erreur_non_enregistre' => '<b>Erreur :</b> l’adresse <tt>@email_oubli@</tt> n’est pas enregistrée sur ce site.',
	'pass_erreur_non_valide' => '<b>Erreur :</b> cet email <tt>@email_oubli@</tt> n’est pas valide !',
	'pass_erreur_probleme_technique' => '<b>Erreur :</b> à cause d’un problème technique, l’email ne peut pas être envoyé.',
	'pass_espace_prive_bla' => 'L’espace privé de ce site est ouvert aux
		visiteurs, après inscription. Une fois enregistré,
		vous pourrez consulter les articles en cours de rédaction,
		proposer des articles et participer à tous les forums.',
	'pass_forum_bla' => 'Vous avez demandé à intervenir sur un forum
		réservé aux visiteurs enregistrés.',
	'pass_indiquez_cidessous' => 'Indiquez ci-dessous l’adresse email sous laquelle vous
			vous êtes précédemment enregistré. Vous
			recevrez un email vous indiquant la marche à suivre pour
			récupérer votre accès.',
	'pass_mail_passcookie' => '(ceci est un message automatique)
Pour retrouver votre accès au site
@nom_site_spip@ (@adresse_site@)

Veuillez vous rendre à l’adresse suivante :

    @sendcookie@

Vous pourrez alors entrer un nouveau mot de passe
et vous reconnecter au site.

',
	'pass_mot_oublie' => 'Mot de passe oublié',
	'pass_nouveau_enregistre' => 'Votre nouveau mot de passe a été enregistré.',
	'pass_nouveau_pass' => 'Nouveau mot de passe',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Oubli du mot de passe',
	'pass_procedure_changer' => 'Pour modifier votre mot de passe, merci d’indiquer l’adresse email associée à votre compte.',
	'pass_quitter_fenetre' => 'Quitter cette fenêtre',
	'pass_rappel_login' => 'Rappel : votre identifiant (login) est « @login@ ».',
	'pass_recevoir_mail' => 'Vous allez recevoir un email vous indiquant comment retrouver votre accès au site.',
	'pass_retour_public' => 'Retour sur le site public',
	'pass_rien_a_faire_ici' => 'Rien à faire ici.',
	'pass_vousinscrire' => 'Vous inscrire sur ce site',
	'precedent' => 'précédent',
	'previsualisation' => 'Prévisualisation',
	'previsualiser' => 'Prévisualiser',

	// R
	'retour' => 'Retour',

	// S
	'spip_conforme_dtd' => 'SPIP considère ce document comme conforme à son DOCTYPE :',
	'squelette' => 'squelette',
	'squelette_inclus_ligne' => 'squelette inclus, ligne',
	'squelette_ligne' => 'squelette, ligne',
	'stats_visites_et_popularite' => '@visites@ visites ; popularité : @popularite@',
	'suivant' => 'suivant',

	// T
	'taille_go' => '@taille@ Go',
	'taille_ko' => '@taille@ ko',
	'taille_mo' => '@taille@ Mo',
	'taille_octets' => '@taille@ octets',
	'texte_actualite_site_1' => 'Quand vous serez familiarisé(e) avec l’interface, vous pourrez cliquer sur « ',
	'texte_actualite_site_2' => 'interface complète',
	'texte_actualite_site_3' => ' » pour ouvrir plus de possibilités.',
	'texte_creation_automatique_vignette' => 'La création automatique de vignettes de prévisualisation est activée sur ce site. Si vous installez à partir de ce formulaire des images au(x) format(s) @gd_formats@, elles seront accompagnées d’une vignette d’une taille maximale de @taille_preview@ pixels.',
	'texte_documents_associes' => 'Les documents suivants sont associés à l’article,
				mais ils n’y ont pas été directement
				insérés. Selon la mise en page du site public,
				ils pourront apparaître sous forme de documents joints.',
	'texte_erreur_mise_niveau_base' => 'Erreur de base de données lors de la mise à niveau.
		L’image <b>@fichier@</b> n’est pas passée (article @id_article@).
		Notez bien cette référence, réessayez la mise à
		niveau, et enfin vérifiez que les images apparaissent
		toujours dans les articles.',
	'texte_erreur_visiteur' => 'Vous avez tenté d’accéder à l’espace privé avec un login qui ne le permet pas.',
	'texte_inc_auth_1' => 'Vous êtes identifié sous le
		login <b>@auth_login@</b>, mais celui-ci n’existe pas/plus dans la base.
		Essayez de vous',
	'texte_inc_auth_2' => 'reconnecter',
	'texte_inc_auth_3' => ', après avoir éventuellement quitté puis
		redémarré votre navigateur.',
	'texte_inc_config' => 'Les modifications effectuées dans ces pages influent notablement sur le
 fonctionnement de votre site. Nous vous recommandons de ne pas y intervenir tant que vous n’êtes pas
 familier du fonctionnement du système SPIP. <br /><br /><b>Plus
 généralement, il est fortement conseillé
 de laisser la charge de ces pages au webmestre principal de votre site.</b>',
	'texte_inc_meta_1' => 'Le système a rencontré une erreur lors de l’écriture du fichier <code>@fichier@</code>. Veuillez, en tant qu’administrateur du site,',
	'texte_inc_meta_2' => 'vérifier les droits d’écriture',
	'texte_inc_meta_3' => 'sur le répertoire <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'en cours de rédaction',
	'texte_statut_poubelle' => 'à la poubelle',
	'texte_statut_propose_evaluation' => 'proposé à l’évaluation',
	'texte_statut_publie' => 'publié en ligne',
	'texte_statut_refuse' => 'refusé',
	'titre_ajouter_mot_cle' => 'AJOUTER UN MOT-CLÉ :',
	'titre_cadre_raccourcis' => 'RACCOURCIS :',
	'titre_changer_couleur_interface' => 'Changer la couleur de l’interface',
	'titre_image_admin_article' => 'Vous pouvez administrer cet article',
	'titre_image_administrateur' => 'Administrateur',
	'titre_image_aide' => 'De l’aide sur cet élément',
	'titre_image_auteur_supprime' => 'Auteur supprimé',
	'titre_image_redacteur' => 'Rédacteur sans accès',
	'titre_image_redacteur_02' => 'Rédacteur',
	'titre_image_selecteur' => 'Afficher la liste',
	'titre_image_visiteur' => 'Visiteur',
	'titre_joindre_document' => 'JOINDRE UN DOCUMENT',
	'titre_mots_cles' => 'MOTS-CLÉS',
	'titre_probleme_technique' => 'Attention : un problème technique (serveur SQL) empêche l’accès à cette partie du site. Merci de votre compréhension.',
	'titre_publier_document' => 'PUBLIER UN DOCUMENT DANS CETTE RUBRIQUE',
	'titre_signatures_attente' => 'Signatures en attente de validation',
	'titre_signatures_confirmees' => 'Signatures confirmées',
	'titre_statistiques' => 'Statistiques du site',
	'titre_titre_document' => 'Titre du document :',
	'todo' => 'à venir',
	'trad_definir_reference' => 'Choisir "@titre@" comme référence des traductions',
	'trad_reference' => '(référence des traductions)',

	// Z
	'zbug_balise_b_aval' => ' : balise B en aval',
	'zbug_balise_inexistante' => 'Balise @balise@ mal déclarée pour @from@',
	'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@',
	'zbug_boucle' => 'boucle',
	'zbug_boucle_recursive_undef' => 'Boucle récursive non définie : @nom@',
	'zbug_calcul' => 'calcul',
	'zbug_champ_hors_boucle' => 'Champ @champ@ hors boucle',
	'zbug_champ_hors_motif' => 'Champ @champ@ hors d’un contexte @motif@',
	'zbug_code' => 'code',
	'zbug_critere_inconnu' => 'Critère inconnu @critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} sur une table sans clef primaire atomique',
	'zbug_distant_interdit' => 'Externe interdit', # Contexte : une base de données "externe", pas gérée par SPIP, mais que SPIP 1.8 sait utiliser dans ses boucles -- seul problèmes certaines manipulations sont interdites sur ces bases-là.
	'zbug_doublon_table_sans_cle_primaire' => 'Doublons sur une table sans clef primaire atomique',
	'zbug_doublon_table_sans_index' => 'Doublons sur une table sans index',
	'zbug_erreur_boucle_double' => 'Double définition de la boucle @id@',
	'zbug_erreur_boucle_fermant' => 'Boucle @id@ non fermée',
	'zbug_erreur_boucle_syntaxe' => 'Syntaxe de la boucle @id@ incorrecte',
	'zbug_erreur_compilation' => 'Erreur de compilation',
	'zbug_erreur_execution_page' => 'Erreur d’exécution',
	'zbug_erreur_filtre' => 'Filtre @filtre@ non défini',
	'zbug_erreur_meme_parent' => 'Le critère {meme_parent} ne s’applique qu’aux boucles (FORUMS) ou (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Erreur(s) dans le squelette',
	'zbug_hors_compilation' => 'Hors Compilation',
	'zbug_info_erreur_squelette' => 'Erreur sur le site',
	'zbug_inversion_ordre_inexistant' => 'Inversion d’un ordre inexistant',
	'zbug_pagination_sans_critere' => 'Balise #PAGINATION sans critère {pagination} ou employé dans une boucle récursive',
	'zbug_parametres_inclus_incorrects' => 'Paramètre d’inclusion incorrect : @param@',
	'zbug_profile' => 'Temps de calcul : @time@',
	'zbug_resultat' => 'résultat',
	'zbug_serveur_indefini' => 'Serveur SQL indéfini',
	'zbug_statistiques' => 'Statistiques des requêtes SQL classées par durée',
	'zbug_table_inconnue' => 'Table SQL « @table@ » inconnue',
	'zxml_connus_attributs' => 'attributs connus',
	'zxml_de' => 'de',
	'zxml_inconnu_attribut' => 'attribut inconnu',
	'zxml_inconnu_balise' => 'balise inconnue',
	'zxml_inconnu_entite' => 'entité inconnue',
	'zxml_inconnu_id' => 'ID inconnu',
	'zxml_mais_de' => 'mais de',
	'zxml_non_conforme' => 'n’est pas conforme au motif',
	'zxml_non_fils' => 'n’est pas un fils de',
	'zxml_nonvide_balise' => 'balise non vide',
	'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans',
	'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte',
	'zxml_survoler' => 'survoler pour voir les corrects',
	'zxml_valeur_attribut' => 'valeur de l’attribut',
	'zxml_vide_balise' => 'balise vide',
	'zxml_vu' => 'vu auparavant'
);

?>
